import 'dart:async';

import 'package:flutter/material.dart';

class RecupTextOrButtonFormField extends StatefulWidget {
  final TextEditingController? controller;
  final String? initialValue;
  final String label;
  final String? Function(String?)? validator;
  final String? hintText;
  final Widget? suffixIcon;
  final Widget? prefixIcon;
  final TextAlign textAlign;
  final void Function(String?)? onSaved;
  final void Function()? onTap;
  final TextInputType? keyboardType;
  final bool isButton;
  final bool? isDense;
  final Function(String)? onChanged;

  const RecupTextOrButtonFormField({
    Key? key,
    this.controller,
    this.initialValue,
    this.label = '',
    this.suffixIcon,
    this.prefixIcon,
    this.textAlign = TextAlign.start,
    this.onSaved,
    this.onTap,
    this.keyboardType,
    this.isButton = false,
    this.isDense,
    this.hintText,
    this.validator,
    this.onChanged,
  }) : super(key: key);

  @override
  State<RecupTextOrButtonFormField> createState() =>
      _RecupTextOrButtonFormFieldState();
}

class _RecupTextOrButtonFormFieldState
    extends State<RecupTextOrButtonFormField> {
  @override
  Widget build(BuildContext context) {
    final isPassWord = widget.keyboardType == TextInputType.visiblePassword;
    final obscure = ValueNotifier(true);

    Timer? _debounce;
    _onSearchChanged(String value) {
      if (_debounce?.isActive ?? false) _debounce?.cancel();
      _debounce = Timer(const Duration(milliseconds: 500), () {
        widget.onChanged!(value);
      });
    }

    @override
    void dispose() {
      _debounce?.cancel();
      super.dispose();
    }

    return AnimatedBuilder(
      animation: obscure,
      builder: (context, child) {
        return TextFormField(
          validator: widget.validator,
          controller: widget.controller,
          initialValue: widget.initialValue,
          textAlign: widget.textAlign,
          onSaved: widget.onSaved,
          onTap: widget.onTap,
          onChanged: (value) {
            if (widget.onChanged != null) {
              _onSearchChanged(value);
            }
          },
          obscureText: isPassWord ? obscure.value : false,
          keyboardType:
              widget.isButton ? TextInputType.none : widget.keyboardType,
          decoration: InputDecoration(
            hintText: widget.hintText,
            isDense: widget.isDense,
            label: Text(widget.label),
            suffixIcon: isPassWord
                ? GestureDetector(
                    onTap: () {
                      obscure.value = !obscure.value;
                    },
                    child: SizedBox(
                      width: 50,
                      child: Icon(
                        Icons.visibility,
                        color: obscure.value
                            ? Theme.of(context).disabledColor
                            : Theme.of(context).backgroundColor,
                      ),
                    ),
                  )
                : widget.suffixIcon,
            prefixIcon: widget.prefixIcon,
            border: OutlineInputBorder(
              borderRadius: BorderRadius.circular(100),
            ),
            focusedBorder: widget.isButton
                ? OutlineInputBorder(
                    borderRadius: BorderRadius.circular(100),
                    borderSide: const BorderSide(
                      color: Colors.white,
                    ),
                  )
                : null,
          ),
        );
      },
    );
  }
}
