import 'package:flutter/material.dart';

class RecupCardOne extends StatelessWidget {
  final String backgroundImage;
  final Widget iconButton;
  final String titulo;
  final String subtitulo;
  final Widget? child;
  final bool isSmallCard;
  final Widget? widgetTitle;
  final void Function()? onTap;
  final double? height;
  const RecupCardOne({
    Key? key,
    this.onTap,
    required this.backgroundImage,
    required this.iconButton,
    required this.titulo,
    required this.subtitulo,
    required this.child,
    this.isSmallCard = true,
    this.widgetTitle,
    this.height,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final mediaQuerySize = MediaQuery.of(context).size;
    return InkWell(
      onTap: onTap,
      child: Padding(
        padding: const EdgeInsets.only(left: 8.0, right: 8.0, top: 8.0),
        child: SizedBox(
          height: height,
          width: isSmallCard ? 176 : mediaQuerySize.width * 0.9,
          child: Card(
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(15.0),
            ),
            color: Theme.of(context).colorScheme.background,
            child: SizedBox(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Container(
                    height: isSmallCard ? 110 : 260,
                    decoration: BoxDecoration(
                      image: DecorationImage(
                        fit: BoxFit.cover,
                        image: NetworkImage(backgroundImage),
                      ),
                      borderRadius: const BorderRadius.only(
                        topLeft: Radius.circular(10),
                        topRight: Radius.circular(10),
                      ),
                    ),
                    child: Padding(
                      padding:
                          const EdgeInsets.only(left: 10, top: 15, right: 10),
                      child: Align(
                        alignment: Alignment.topLeft,
                        child: iconButton,
                      ),
                    ),
                  ),
                  Padding(
                    padding:
                        const EdgeInsets.only(top: 10, left: 20, right: 20),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Visibility(
                              visible: isSmallCard,
                              replacement: Row(
                                mainAxisAlignment:
                                    MainAxisAlignment.spaceBetween,
                                children: [
                                  SizedBox(
                                    width: widgetTitle != null
                                        ? mediaQuerySize.width * 0.55
                                        : mediaQuerySize.width * 0.75,
                                    child: Text(
                                      titulo,
                                      maxLines: 2,
                                      overflow: TextOverflow.ellipsis,
                                      style: Theme.of(context)
                                          .textTheme
                                          .titleSmall,
                                    ),
                                  ),
                                  Visibility(
                                    visible: widgetTitle != null,
                                    child: widgetTitle ?? const SizedBox(),
                                  )
                                ],
                              ),
                              child: Text(
                                titulo,
                                maxLines: 2,
                                overflow: TextOverflow.ellipsis,
                                style: Theme.of(context).textTheme.titleSmall,
                              ),
                            ),
                            Padding(
                              padding:
                                  const EdgeInsets.only(top: 5, bottom: 10),
                              child: Text(
                                subtitulo,
                                maxLines: 2,
                                overflow: TextOverflow.ellipsis,
                                style: Theme.of(context).textTheme.labelSmall,
                              ),
                            ),
                          ],
                        ),
                        child ?? const SizedBox(),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
